==> jc-1.4.0.tar.gz: java/rmi/activation/UnknownGroupException.h <==
// public class java.rmi.activation.UnknownGroupException

// class file dependencies
// @dep_class c5feb325780a6cd7 java_lang_Exception
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable
// @dep_class fd8995a120b8f60d java_rmi_activation_ActivationException
// @dep_class f96a3f4133dadcb4 java_rmi_activation_UnknownGroupException

// header file dependencies
// @dep_header java_rmi_activation_ActivationException

#include "java/rmi/activation/ActivationException.h"

#ifndef _JC_java_rmi_activation_UnknownGroupException_H_
#define _JC_java_rmi_activation_UnknownGroupException_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_java_rmi_activation_UnknownGroupException$sub_refs	_jc_java_rmi_activation_UnknownGroupException$sub_refs;
typedef struct _jc_java_rmi_activation_UnknownGroupException$sub_nonrefs	_jc_java_rmi_activation_UnknownGroupException$sub_nonrefs;
typedef struct _jc_java_rmi_activation_UnknownGroupException$refs	_jc_java_rmi_activation_UnknownGroupException$refs;
typedef struct _jc_java_rmi_activation_UnknownGroupException$nonrefs	_jc_java_rmi_activation_UnknownGroupException$nonrefs;
typedef struct _jc_java_rmi_activation_UnknownGroupException$object	_jc_java_rmi_activation_UnknownGroupException$object;

typedef struct _jc_java_rmi_activation_UnknownGroupException$fields_struct	_jc_java_rmi_activation_UnknownGroupException$fields_struct;
typedef const struct _jc_java_rmi_activation_UnknownGroupException$vmethods	_jc_java_rmi_activation_UnknownGroupException$vmethods;
typedef const struct _jc_java_rmi_activation_UnknownGroupException$vtable	_jc_java_rmi_activation_UnknownGroupException$vtable;
typedef const struct _jc_java_rmi_activation_UnknownGroupException$vtype	_jc_java_rmi_activation_UnknownGroupException$vtype;

// Class fields structure
struct _jc_java_rmi_activation_UnknownGroupException$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_java_rmi_activation_UnknownGroupException$fields_struct _jc_java_rmi_activation_UnknownGroupException$class_fields;

// Constructors
extern void _jc_java_rmi_activation_UnknownGroupException$method$_init$c31b894660454d13(_jc_env *, struct _jc_java_rmi_activation_UnknownGroupException$object *, struct _jc_java_lang_String$object *);

// Virtual methods structure
struct _jc_java_rmi_activation_UnknownGroupException$vmethods {
};

// Vtable
struct _jc_java_rmi_activation_UnknownGroupException$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Exception$vmethods	java_lang_Exception;
	_jc_java_rmi_activation_ActivationException$vmethods	java_rmi_activation_ActivationException;
	_jc_java_rmi_activation_UnknownGroupException$vmethods	java_rmi_activation_UnknownGroupException;
};

// Vtype
struct _jc_java_rmi_activation_UnknownGroupException$vtype {
	_jc_type			type;
	_jc_java_rmi_activation_UnknownGroupException$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_rmi_activation_UnknownGroupException$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_rmi_activation_UnknownGroupException$refs {
    _jc_java_rmi_activation_UnknownGroupException$sub_refs	java_rmi_activation_UnknownGroupException;
    _jc_java_rmi_activation_ActivationException$sub_refs	java_rmi_activation_ActivationException;
    _jc_java_lang_Exception$sub_refs	java_lang_Exception;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_rmi_activation_UnknownGroupException$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_rmi_activation_UnknownGroupException$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Exception$sub_nonrefs	java_lang_Exception;
    _jc_java_rmi_activation_ActivationException$sub_nonrefs	java_rmi_activation_ActivationException;
    _jc_java_rmi_activation_UnknownGroupException$sub_nonrefs	java_rmi_activation_UnknownGroupException;
};

// Object instance structure
struct _jc_java_rmi_activation_UnknownGroupException$object {
	_jc_java_rmi_activation_UnknownGroupException$refs	refs[0];
	_jc_word		lockword;
	_jc_java_rmi_activation_UnknownGroupException$vtype	*vtype;
	_jc_java_rmi_activation_UnknownGroupException$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_rmi_activation_UnknownGroupException$vtype _jc_java_rmi_activation_UnknownGroupException$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_rmi_activation_UnknownGroupException, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_rmi_activation_UnknownGroupException$class_object;

#endif	/* _JC_java_rmi_activation_UnknownGroupException_H_ */

==> jc-1.4.6.tar.gz: java/rmi/activation/UnknownGroupException.h <==
// public class java.rmi.activation.UnknownGroupException

// class file dependencies
// @dep_class c5feb325780a6cd7 java_lang_Exception
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable
// @dep_class fd8995a120b8f60d java_rmi_activation_ActivationException
// @dep_class f96a3f4133dadcb4 java_rmi_activation_UnknownGroupException

// header file dependencies
// @dep_header java_rmi_activation_ActivationException

#include "java/rmi/activation/ActivationException.h"

#ifndef _JC_java_rmi_activation_UnknownGroupException_H_
#define _JC_java_rmi_activation_UnknownGroupException_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_java_rmi_activation_UnknownGroupException$sub_refs	_jc_java_rmi_activation_UnknownGroupException$sub_refs;
typedef struct _jc_java_rmi_activation_UnknownGroupException$sub_nonrefs	_jc_java_rmi_activation_UnknownGroupException$sub_nonrefs;
typedef struct _jc_java_rmi_activation_UnknownGroupException$refs	_jc_java_rmi_activation_UnknownGroupException$refs;
typedef struct _jc_java_rmi_activation_UnknownGroupException$nonrefs	_jc_java_rmi_activation_UnknownGroupException$nonrefs;
typedef struct _jc_java_rmi_activation_UnknownGroupException$object	_jc_java_rmi_activation_UnknownGroupException$object;

typedef struct _jc_java_rmi_activation_UnknownGroupException$fields_struct	_jc_java_rmi_activation_UnknownGroupException$fields_struct;
typedef const struct _jc_java_rmi_activation_UnknownGroupException$vmethods	_jc_java_rmi_activation_UnknownGroupException$vmethods;
typedef const struct _jc_java_rmi_activation_UnknownGroupException$vtable	_jc_java_rmi_activation_UnknownGroupException$vtable;
typedef const struct _jc_java_rmi_activation_UnknownGroupException$vtype	_jc_java_rmi_activation_UnknownGroupException$vtype;

// Class fields structure
struct _jc_java_rmi_activation_UnknownGroupException$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_java_rmi_activation_UnknownGroupException$fields_struct _jc_java_rmi_activation_UnknownGroupException$class_fields;

// Constructors
extern void _jc_java_rmi_activation_UnknownGroupException$method$_init$c31b894660454d13(_jc_env *, struct _jc_java_rmi_activation_UnknownGroupException$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_java_rmi_activation_UnknownGroupException$vmethods {
};

// Vtable
struct _jc_java_rmi_activation_UnknownGroupException$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Exception$vmethods	java_lang_Exception;
	_jc_java_rmi_activation_ActivationException$vmethods	java_rmi_activation_ActivationException;
	_jc_java_rmi_activation_UnknownGroupException$vmethods	java_rmi_activation_UnknownGroupException;
};

// Vtype
struct _jc_java_rmi_activation_UnknownGroupException$vtype {
	_jc_type			type;
	_jc_java_rmi_activation_UnknownGroupException$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_rmi_activation_UnknownGroupException$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_rmi_activation_UnknownGroupException$refs {
    _jc_java_rmi_activation_UnknownGroupException$sub_refs	java_rmi_activation_UnknownGroupException;
    _jc_java_rmi_activation_ActivationException$sub_refs	java_rmi_activation_ActivationException;
    _jc_java_lang_Exception$sub_refs	java_lang_Exception;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_rmi_activation_UnknownGroupException$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_rmi_activation_UnknownGroupException$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Exception$sub_nonrefs	java_lang_Exception;
    _jc_java_rmi_activation_ActivationException$sub_nonrefs	java_rmi_activation_ActivationException;
    _jc_java_rmi_activation_UnknownGroupException$sub_nonrefs	java_rmi_activation_UnknownGroupException;
};

// Object instance structure
struct _jc_java_rmi_activation_UnknownGroupException$object {
	_jc_java_rmi_activation_UnknownGroupException$refs	refs[0];
	_jc_word		lockword;
	_jc_java_rmi_activation_UnknownGroupException$vtype	*vtype;
	_jc_java_rmi_activation_UnknownGroupException$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_rmi_activation_UnknownGroupException$vtype _jc_java_rmi_activation_UnknownGroupException$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_rmi_activation_UnknownGroupException, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_rmi_activation_UnknownGroupException$class_object;

#endif	/* _JC_java_rmi_activation_UnknownGroupException_H_ */
